@@ -1,9 +1,10 @@
 from . import utils
 from .event import Event
 from .handlers import register
+from .pagination import paginate
 from .require import require
 
-__all__ = ["require", "register", "Event", "utils"]
+__all__ = ["require", "register", "paginate", "Event", "utils"]
 # , "django_asgi_app"]
 # , "django_wsgi_app"]
 # , "flask_asgi_app"]
